﻿Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.IO
Imports System.Reflection
Imports System.Diagnostics
''' <summary>
''' 内部的な共通クラス
''' </summary>
Class Common

#Region "定数"
    '**************
    '* 制御コード
    '**************
    ''' <summary> ENQ(ステータス要求コマンド)</summary>
    Public Const ENQ As Byte = &H5
    ''' <summary> ACK</summary>
    Public Const ACK As Byte = &H6
    ''' <summary> NAK</summary>
    Public Const NAK As Byte = &H15
    ''' <summary> CAN(キャンセルコマンド)</summary>
    Public Const CAN As Byte = &H18
    ''' <summary> STX</summary>
    Public Const STX As Byte = &H2
    ''' <summary> ETX</summary>
    Public Const ETX As Byte = &H3
    ''' <summary> ESC</summary>
    Public Const ESC As Byte = &H1B

    '*****************
    '* ステータス種別
    '*****************
    ''' <summary> 送信可・印刷完了</summary>
    Public Const STR_OK As Integer = 0
    ''' <summary> 待機</summary>
    Public Const STR_STANDBY As Integer = -1
    ''' <summary> イニシャル</summary>
    Public Const STR_INITIAL As Integer = -2
    ''' <summary> 通過中</summary>
    Public Const STR_WAIT_PASS As Integer = -3
    ''' <summary> 復旧可能(オフライン)</summary>
    Public Const STR_OFF_LINE As Integer = -21
    ''' <summary> 復旧可能(ヘッドオープン)</summary>
    Public Const STR_HEAD_OPEN As Integer = -22
    ''' <summary> 復旧可能(ペーパーエンド)</summary>
    Public Const STR_PAPER_END As Integer = -23
    ''' <summary> 復旧可能(リボンエンド)</summary>
    Public Const STR_RIBON_END As Integer = -24
    ''' <summary> 復旧可能(センサエラー)</summary>
    Public Const STR_SENSOR_ERROR As Integer = -25
    ''' <summary> 復旧可能(カバーオープン)</summary>
    Public Const STR_COVER_OPENING As Integer = -26
    ''' <summary> 復旧不可</summary>
    Public Const STR_NOT_POS_RES As Integer = -99

    '**************
    '* その他
    '**************
    ''' <summary> ステータス位置</summary>
    Public Const STR_INDEX As Integer = 3

#End Region

#Region "共通関数"
    ''' ------------------------------------------------------------------------------------------------
    ''' <summary>
    ''' dllが置かれている場所にログを出力する
    ''' </summary>
    ''' <param name="prmStrClassName">クラス名</param>
    ''' <param name="prmStrMethodName">メソッド名</param>
    ''' <param name="prmStrlogMsg">ログメッセージ</param>
    ''' ------------------------------------------------------------------------------------------------
    Public Shared Sub outputLog(ByVal prmStrClassName As String, ByVal prmStrMethodName As String, _
                                ByVal prmStrlogMsg As String)

        Dim sw As StreamWriter = Nothing

        Try
            ' ファイルオープン
            sw = New System.IO.StreamWriter(getAppPath() & "\satopt.log", True, System.Text.Encoding.GetEncoding(932))

            ' ログ出力
            sw.WriteLine(DateTime.Now.ToString("G") & ":" & prmStrClassName & Chr(9) & prmStrMethodName & Chr(9) & prmStrlogMsg & Chr(10))
        Finally
            If sw IsNot Nothing Then
                sw.Close()
            End If
        End Try

    End Sub

    ''' -----------------------------------------------------------------------------------------------------
    ''' <summary>
    ''' dllが置かれている場所にログを出力する
    ''' </summary>
    ''' <param name="prmStrClassName">クラス名</param>
    ''' <param name="prmStrMethodName">メソッド名</param>
    ''' <param name="prmStrlogMsg">ログメッセージ</param>
    ''' -----------------------------------------------------------------------------------------------------
    <Conditional("DEBUG")> _
    Public Shared Sub outputDebugLog(ByVal prmStrClassName As String, ByVal prmStrMethodName As String, _
                                        ByVal prmStrlogMsg As String)

        outputLog(prmStrClassName, prmStrMethodName, "[デバック]" & Chr(9) & "" & prmStrlogMsg)

    End Sub

    ''' ------------------------------------------------------------------------------------------
    ''' <summary>
    ''' 印刷送信条件確認
    ''' </summary>
    ''' <param name="prmBytStatus">チェックするステータス</param>
    ''' <returns>
    ''' STR_OK：送信可
    ''' STR_STANDBY：待機
    ''' STR_WAIT_PASS：通過待ち
    ''' STR_OFF_LINE：復旧可能(オフライン)
    ''' STR_HEAD_OPEN：復旧可能(ヘッドオープン)
    ''' STR_PAPER_END：復旧可能(ペーパーエンド)
    ''' STR_RIBON_END：復旧可能(リボンエンド)
    ''' STR_SENSOR_ERROR：復旧可能(センサエラー)
    ''' STR_COVER_OPENING：復旧可能(カバーオープン)
    ''' STR_NOT_POS_RES：復旧不可
    ''' </returns>
    ''' ------------------------------------------------------------------------------------------
    Public Shared Function chkPrintTransmissionCondition(ByVal prmBytStatus As Byte) As Integer

        Dim intRet As Integer = STR_NOT_POS_RES

        Select Case prmBytStatus
            Case &H2A
                '【イニシャル】
                ' [2A]イニシャル
                intRet = STR_INITIAL
                Exit Select
            Case &H30, &H31, &H32, &H33
                '【オフライン状態】
                ' [30]エラーなし
                ' [31]リボン/ラベル ニアエンド
                ' [32]バッファニヤフル
                ' [33]リボン/ラベル ニアエンド＆バッファニアフル

                ' 復旧可能なエラー/オフライン
                intRet = STR_OFF_LINE
                Exit Select
            Case &H41, &H42
                '【オンライン状態 & 受信待ち】
                ' [41]エラーなし
                ' [42]リボン/ラベル ニアエンド

                ' 送信可
                intRet = STR_OK
                Exit Select
            Case &H43, &H44, _
                 &H47, &H48, &H49, &H4A, _
                 &H4D, &H4E, &H4F, &H50, _
                 &H53, &H54, &H55, &H56, _
                 &H6F, &H70, &H71, &H72
                '【オンライン状態 & 受信待ち】
                ' [43]バッファニヤフル
                ' [44]リボン/ラベル ニアエンド＆バッファニアフル

                '【オンライン状態 & 印字中】
                ' [47]エラーなし
                ' [48]リボン/ラベル ニアエンド
                ' [49]バッファニヤフル
                ' [4A]リボン/ラベル ニヤエンド＆バッファニアフル

                '【オンライン状態 & 印字待ち/通過待ち】
                ' [4D]エラーなし
                ' [4E]リボン/ラベル ニアエンド
                ' [4F]バッファニヤフル
                ' [50]リボン/ラベル ニヤエンド＆バッファニアフル

                ' 【オンライン状態 & 解析・編集中】
                ' [53]エラーなし
                ' [54]リボン/ラベル ニアエンド
                ' [55]バッファニヤフル
                ' [56]リボン/ラベル ニアエンド＆バッファニアフル

                '【オンライン状態 & 印字吸着起動信号待ち／貼付中】
                ' [6F]エラーなし
                ' [70]リボン/ラベル ニアエンド
                ' [71]バッファニヤフル
                ' [72]リボン/ラベル ニアエンド＆バッファニアフル

                ' 待機
                intRet = STR_STANDBY
                Exit Select
            Case &H73, &H74, &H75, &H76

                '【オンライン状態 & 通過中】
                ' [73]エラーなし
                ' [74]リボン/ラベル ニアエンド
                ' [75]バッファニヤフル
                ' [76]リボン/ラベル ニアエンド＆バッファニアフル

                ' 通過待ち
                intRet = STR_WAIT_PASS
                Exit Select
            Case &H61
                ' [61]バッファオーバー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
            Case &H62
                ' [62]ヘッドオープン

                ' 復旧可能なエラー
                intRet = STR_COVER_OPENING
                Exit Select
            Case &H63
                ' [63]ペーパーエンド／センサエラー／⽤紙詰まりエラー

                ' 復旧可能なエラー
                intRet = STR_PAPER_END
                Exit Select
            Case &H64
                ' [64]リボンエンド

                ' 復旧可能なエラー
                intRet = STR_RIBON_END
                Exit Select
            Case &H67
                ' [67]ヘッドエラー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
            Case &H69, &H6B, &H6C, &H23, &H24, &H25, &H2B
                ' [69]カードエラー
                ' [6B]その他のエラー
                ' [6C]ラベル貼付エラー

                ' [23]ラベル吸着エラー
                ' [24]能⼒オーバーエラー
                ' [25]シリンダ動作不良エラー
                ' [2B]ユーザー専⽤のエラー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
        End Select

        Return intRet

    End Function

    ''' ------------------------------------------------------------------------------------------
    ''' <summary>
    ''' 印刷完了条件確認
    ''' </summary>
    ''' <param name="prmBytStatus">チェックするステータス</param>
    ''' <returns>
    ''' STR_OK：印刷完了
    ''' STR_STANDBY：待機
    ''' STR_WAIT_PASS：通過待ち
    ''' STR_OFF_LINE：復旧可能(オフライン)
    ''' STR_PAPER_END：復旧可能(バッテリエンド)
    ''' STR_SENSOR_ERROR：復旧可能(センサエラー)
    ''' STR_COVER_OPENING：復旧可能(カバーオープン)
    ''' STR_NOT_POS_RES：復旧不可
    ''' </returns>
    ''' ------------------------------------------------------------------------------------------
    Public Shared Function chkPrintCompletionCondition(ByVal prmBytStatus As Byte) As Integer

        Dim intRet As Integer = STR_NOT_POS_RES

        Select Case prmBytStatus
            Case &H2A
                '【イニシャル】
                ' [2A]イニシャル
                intRet = STR_INITIAL
                Exit Select
            Case &H30, &H31, &H32, &H33
                '【オフライン状態】
                ' [30]エラーなし
                ' [31]リボン/ラベル ニアエンド
                ' [32]バッファニヤフル
                ' [33]リボン/ラベル ニアエンド＆バッファニアフル

                ' 復旧可能なエラー/オフライン
                intRet = STR_OFF_LINE
                Exit Select
            Case &H41, &H42, &H43, &H44
                '【オンライン状態 & 受信待ち】
                ' [41]エラーなし
                ' [42]リボン/ラベル ニアエンド
                ' [43]バッファニヤフル
                ' [44]リボン/ラベル ニアエンド＆バッファニアフル

                ' 送信可
                intRet = STR_OK
                Exit Select
            Case &H47, &H48, &H49, &H4A, _
                 &H4D, &H4E, &H4F, &H50, _
                 &H53, &H54, &H55, &H56, _
                 &H6F, &H70, &H71, &H72

                '【オンライン状態 & 印字中】
                ' [47]エラーなし
                ' [48]リボン/ラベル ニアエンド
                ' [49]バッファニヤフル
                ' [4A]リボン/ラベル ニアエンド＆バッファニアフル

                '【オンライン状態 & 印字待ち/通過待ち】
                ' [4D]エラーなし
                ' [4E]リボン/ラベル ニアエンド
                ' [4F]バッファニヤフル
                ' [50]リボン/ラベル ニアエンド＆バッファニアフル

                ' 【オンライン状態 & 解析・編集中】
                ' [53]エラーなし
                ' [54]リボン/ラベル ニアエンド
                ' [55]バッファニヤフル
                ' [56]リボン/ラベル ニアエンド＆バッファニアフル

                '【オンライン状態 & 印字吸着起動信号待ち／貼付中】
                ' [6F]エラーなし
                ' [70]リボン/ラベル ニアエンド
                ' [71]バッファニヤフル
                ' [72]リボン/ラベル ニアエンド＆バッファニアフル

                ' 待機
                intRet = STR_STANDBY
                Exit Select

            Case &H73, &H74, &H75, &H76

                '【オンライン状態 & 通過中】
                ' [73]エラーなし
                ' [74]リボン/ラベル ニアエンド
                ' [75]バッファニヤフル
                ' [76]リボン/ラベル ニアエンド＆バッファニアフル

                ' 通過待ち
                intRet = STR_WAIT_PASS
                Exit Select
            Case &H61
                ' [61]バッファオーバー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
            Case &H62
                ' [62]ヘッドオープン

                ' 復旧可能なエラー
                intRet = STR_COVER_OPENING
                Exit Select
            Case &H63
                ' [63]ペーパーエンド／センサエラー／⽤紙詰まりエラー

                ' 復旧可能なエラー
                intRet = STR_PAPER_END
                Exit Select
            Case &H64
                ' [64]リボンエンド

                ' 復旧可能なエラー
                intRet = STR_RIBON_END
                Exit Select
            Case &H67
                ' [67]ヘッドエラー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
            Case &H69, &H6B, &H6C, &H23, &H24, &H25, &H2B
                ' [69]カードエラー
                ' [6B]その他のエラー
                ' [6C]ラベル貼付エラー

                ' [23]ラベル吸着エラー
                ' [24]能⼒オーバーエラー
                ' [25]シリンダ動作不良エラー
                ' [2B]ユーザー専⽤のエラー

                ' 復旧不可
                intRet = STR_NOT_POS_RES
                Exit Select
        End Select

        Return intRet

    End Function

    ''' ------------------------------------------------------------------------------
    ''' <summary>
    ''' 自分がいるパスを返す
    ''' </summary>
    ''' <returns>
    ''' 自分がいるパス
    ''' </returns>
    ''' ------------------------------------------------------------------------------
    Public Shared Function getAppPath() As String

        Dim strAppName As String            'exe名も含むアプリケーションのパス
        Dim strAppPath As String            'exe名を取り除いたアプリケーションのパス

        'アプリケーションのフルパスを取得する
        strAppName = Assembly.GetExecutingAssembly().GetName().CodeBase

        'exe名を取り除く
        strAppPath = System.IO.Path.GetDirectoryName( _
        System.Reflection.Assembly.GetExecutingAssembly().Location)

        'パスを戻り値として返す
        Return strAppPath

    End Function

#End Region

End Class
